==> canesm_process-2025.1.0.tar.gz: canesm_process-2025.1.0/src/canproc/runners/dask.py <==
from canproc.dag.dag import DAG
from dask.utils import apply
import dask
from typing import Any, Callable, Literal
from enum import Enum


DaskTaskType = tuple[Callable, Callable, list, dict]
DaskOutputType = str | list[str]
DaskDagType = dict[str, DaskTaskType]


class DaskRunner:
    """
    Use dask to run a directed acyclic graph

    Attributes
    ----------
    scheduler : Callable

    Examples
    --------
    >>> from canproc.runners import DaskRunner
    >>> from canproc import DAG, DAGProcess
    >>> dag = DAG(dag=[DAGProcess(name='array', function='np.arange', args=[0, 10])], output='array')
    >>> runner = DaskRunner()
    >>> array = runner.run(dag)
    """

    def __init__(
        self,
        scheduler: Literal["threads", "processes", "single-threaded", "syncronous"] = "threads",
    ):
        """

        Parameters
        ----------
        scheduler : str, optional
            Accepts "threads", "processes" or "single-threaded" by default "threads"

        """
        match scheduler:
            case "threads":
                self.scheduler = dask.threaded.get
            case "processes":
                self.scheduler = dask.multiprocessing.get
            case "syncronous":
                self.scheduler = dask.get
            case "single-threaded":
                self.scheduler = dask.get
            case _:
                raise ValueError(f"scheduler {scheduler} is not recognized")

    @staticmethod
    def create_dag(
        dag: DAG,
    ) -> tuple[DaskDagType, DaskOutputType]:
        """
        Format the DAG into the format dask expects
        """
        dsk = {}
        for process in dag.dag:
            dsk[process.name] = (apply, process.function, process.args, process.kwargs)
        return dsk, dag.output

    def run(self, dag: DAG, **kwargs) -> Any:
        """Run a DAG using the dask scheduler

        Parameters
        ----------
        dag : DAG
            Directed Acyclic Graph that defines the processes and outputs

        Returns
        -------
        output
            Output of the dag

        """
        dsk, output = self.create_dag(dag)
        return self.scheduler(dsk, output, **kwargs)

==> canesm_process-2025.1.1.tar.gz: canesm_process-2025.1.1/src/canproc/runners/dask.py <==
from canproc.dag.dag import DAG
from dask.utils import apply
import dask
from typing import Any, Callable, Literal


DaskTaskType = tuple[Callable, Callable, list, dict]
DaskOutputType = str | list[str]
DaskDagType = dict[str, DaskTaskType]


class DaskRunner:
    """
    Use dask to run a directed acyclic graph

    Attributes
    ----------
    scheduler : Callable

    Examples
    --------
    >>> from canproc.runners import DaskRunner
    >>> from canproc import DAG, DAGProcess
    >>> dag = DAG(dag=[DAGProcess(name='array', function='np.arange', args=[0, 10])], output='array')
    >>> runner = DaskRunner()
    >>> array = runner.run(dag)
    """

    def __init__(
        self,
        scheduler: Literal["threads", "processes", "single-threaded", "syncronous"] = "threads",
    ):
        """

        Parameters
        ----------
        scheduler : str, optional
            Accepts "threads", "processes" or "single-threaded" by default "threads"

        """
        match scheduler:
            case "threads":
                self.scheduler = dask.threaded.get
            case "processes":
                self.scheduler = dask.multiprocessing.get
            case "syncronous":
                self.scheduler = dask.get
            case "single-threaded":
                self.scheduler = dask.get
            case _:
                raise ValueError(f"scheduler {scheduler} is not recognized")

    @staticmethod
    def create_dag(
        dag: DAG,
    ) -> tuple[DaskDagType, DaskOutputType]:
        """
        Format the DAG into the format dask expects
        """
        dsk = {}
        for process in dag.dag:
            dsk[process.name] = (
                apply,
                process.function,
                process.args,
                process.kwargs if process.kwargs else {},
            )
        return dsk, dag.output

    def run(self, dag: DAG, **kwargs) -> Any:
        """Run a DAG using the dask scheduler

        Parameters
        ----------
        dag : DAG
            Directed Acyclic Graph that defines the processes and outputs

        Returns
        -------
        output
            Output of the dag

        """
        dsk, output = self.create_dag(dag)
        return self.scheduler(dsk, output, **kwargs)
